@@ -30,6 +30,7 @@ class IdentityEndpoint(BaseEndpoint):
     def __init__(self, middlewares=()):
         super(IdentityEndpoint, self).__init__(middlewares)
         self.communication_manager = None
+        self.app.on_shutdown.append(self.on_shutdown)
 
     def initialize(self, session):
         super(IdentityEndpoint, self).initialize(session)
@@ -89,7 +90,8 @@ class IdentityEndpoint(BaseEndpoint):
         }
     )
     async def list_schemas(self, request):
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
         return Response({"schemas": channel.schemas})
 
     @docs(
@@ -108,7 +110,8 @@ class IdentityEndpoint(BaseEndpoint):
         }
     )
     async def get_pseudonym_public_key(self, request):
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
         return Response({"public_key": ez_b64_encode(channel.public_key_bin)})
 
     @docs(
@@ -167,7 +170,8 @@ class IdentityEndpoint(BaseEndpoint):
         }
     )
     async def list_pseudonym_credentials(self, request):
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
         return Response({"names": [{
             "name": data[0],
             "hash": ez_b64_encode(strip_sha1_padding(attribute_hash)),
@@ -205,7 +209,8 @@ class IdentityEndpoint(BaseEndpoint):
         }
     )
     async def list_subject_credentials(self, request):
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
 
         subject = None
         for peer in channel.peers:
@@ -240,7 +245,8 @@ class IdentityEndpoint(BaseEndpoint):
         }
     )
     async def list_pseudonym_peers(self, request):
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
         return Response({"peers": [ez_b64_encode(peer.public_key.key_to_bin()) for peer in channel.peers]})
 
     @docs(
@@ -279,7 +285,8 @@ class IdentityEndpoint(BaseEndpoint):
         if 'name' not in parameters:
             return Response({"error": "incorrect parameters"}, status=HTTP_BAD_REQUEST)
 
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
         verifier = None
         for peer in channel.peers:
             if peer.public_key.key_to_bin() == ez_b64_decode(request.match_info['verifier_key']):
@@ -328,7 +335,8 @@ class IdentityEndpoint(BaseEndpoint):
         if 'name' not in parameters:
             return Response({"error": "incorrect parameters"}, status=HTTP_BAD_REQUEST)
 
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
         verifier = None
         for peer in channel.peers:
             if peer.public_key.key_to_bin() == ez_b64_decode(request.match_info['verifier_key']):
@@ -379,7 +387,8 @@ class IdentityEndpoint(BaseEndpoint):
         if 'name' not in parameters or 'schema' not in parameters:
             return Response({"error": "incorrect parameters"}, status=HTTP_BAD_REQUEST)
 
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
         authority = None
         for peer in channel.peers:
             if peer.public_key.key_to_bin() == ez_b64_decode(request.match_info['authority_key']):
@@ -430,7 +439,8 @@ class IdentityEndpoint(BaseEndpoint):
         if 'name' not in parameters or 'value' not in parameters:
             return Response({"error": "incorrect parameters"}, status=HTTP_BAD_REQUEST)
 
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
 
         subject = None
         for peer in channel.peers:
@@ -482,7 +492,8 @@ class IdentityEndpoint(BaseEndpoint):
         if 'hash' not in parameters or 'value' not in parameters or 'schema' not in parameters:
             return Response({"error": "incorrect parameters"}, status=HTTP_BAD_REQUEST)
 
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
 
         subject = None
         for peer in channel.peers:
@@ -517,7 +528,8 @@ class IdentityEndpoint(BaseEndpoint):
         }
     )
     async def list_pseudonym_outstanding_attestations(self, request):
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
         formatted = []
         for k, v in channel.attestation_requests.items():
             formatted.append({
@@ -546,7 +558,8 @@ class IdentityEndpoint(BaseEndpoint):
         }
     )
     async def list_pseudonym_outstanding_verifications(self, request):
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
         formatted = []
         for k in channel.verify_requests.keys():
             formatted.append({
@@ -577,7 +590,8 @@ class IdentityEndpoint(BaseEndpoint):
         }
     )
     async def list_pseudonym_verification_output(self, request):
-        channel = await self.communication_manager.load(request.match_info['pseudonym_name'])
+        channel = await self.communication_manager.load(request.match_info['pseudonym_name'],
+                                                        request.headers.get('X-Rendezvous'))
 
         formatted = []
         for k, v in channel.verification_output.items():
@@ -587,3 +601,6 @@ class IdentityEndpoint(BaseEndpoint):
             formatted.append({"hash": ez_b64_encode(k), "reference": ez_b64_encode(v[0][0]), "match": v[0][1]})
 
         return Response({"outputs": formatted})
+
+    async def on_shutdown(self, _):
+        await self.communication_manager.shutdown()
