@@ -81,6 +81,13 @@ class TunnelSettings(object):
         # Maximum number of relay_early cells that are allowed to pass a relay.
         self.max_relay_early = 8
 
+    @classmethod
+    def from_dict(cls, d):
+        result = cls()
+        for k, v in d.items():
+            setattr(result, k, v)
+        return result
+
 
 class TunnelCommunity(Community):
 
@@ -88,13 +95,11 @@ class TunnelCommunity(Community):
     community_id = unhexlify('81ded07332bdc775aa5a46f96de9f8f390bbc9f3')
 
     def __init__(self, *args, **kwargs):
-        self.settings = kwargs.pop('settings', TunnelSettings())
+        settings = kwargs.pop('settings', TunnelSettings())
+        if isinstance(settings, dict):
+            settings = TunnelSettings.from_dict(settings)
+        self.settings = settings
         self.dht_provider = kwargs.pop('dht_provider', None)
-        if isinstance(self.settings, dict):
-            settings = TunnelSettings()
-            for k, v in self.settings.items():
-                setattr(settings, k, v)
-            self.settings = settings
 
         super(TunnelCommunity, self).__init__(*args, **kwargs)
 
@@ -249,7 +254,9 @@ class TunnelCommunity(Community):
                 exit_candidates = self.get_candidates(PEER_FLAG_EXIT_BT)
             elif ctype == CIRCUIT_TYPE_IP_SEEDER:
                 # For introduction points we prefer exit nodes, but perhaps a relay peer would also suffice..
-                exit_candidates = self.get_candidates(PEER_FLAG_EXIT_BT) or self.get_candidates(PEER_FLAG_RELAY)
+                exit_candidates = self.get_candidates(PEER_FLAG_EXIT_BT) \
+                    or self.get_candidates(PEER_FLAG_EXIT_IPV8) \
+                    or self.get_candidates(PEER_FLAG_RELAY)
             else:
                 # For exit nodes that don't exit actual data, we prefer relay candidates,
                 # but we also consider exit candidates.
