@@ -17,6 +17,8 @@ from .tunnel import (CIRCUIT_ID_PORT, CIRCUIT_TYPE_IP_SEEDER, CIRCUIT_TYPE_RP_DO
                      DESTROY_REASON_LEAVE_SWARM, DESTROY_REASON_UNNEEDED, EXIT_NODE, EXIT_NODE_SALT, Hop,
                      IntroductionPoint, PEER_SOURCE_DHT, PEER_SOURCE_PEX, RelayRoute, RendezvousPoint, Swarm,
                      TunnelExitSocket)
+from ...bootstrapping.dispersy.bootstrapper import DispersyBootstrapper
+from ...configuration import DISPERSY_BOOTSTRAPPER
 from ...keyvault.public.libnaclkey import LibNaCLPK
 from ...messaging.anonymization.pex import PexCommunity
 from ...peer import Peer
@@ -481,6 +483,7 @@ class HiddenTunnelCommunity(TunnelCommunity):
             self.logger.error('No IPv8 service object available, cannot start PEXCommunity')
         elif payload.info_hash not in self.pex:
             community = PexCommunity(self.my_peer, self.endpoint, Network(), info_hash=payload.info_hash)
+            community.bootstrappers = [DispersyBootstrapper(**DISPERSY_BOOTSTRAPPER['init'])]
             # Since IPv8 takes a step every .5s until we have 10 peers, the PexCommunity will generate
             # a lot of traffic in case there are <10 peers in existence. Therefore, we slow the walk down to a 5s/step.
             self.ipv8.add_strategy(community, RandomWalk(community, target_interval=5), 10)
